ALSSMs & Cost Functions 
-----------------------

Autonomous Linear State Space Models (ALSSMs) and squared error cost functions using ALSSM models,
see also: `ALSSM Classes`  and `Cost Function Classes` in module :ref:`lmlib_api_statespace`

